@@ -1,9 +1,17 @@
 from lung.controllers._lookahead import Lookahead
 from lung.controllers._pid import PID
+from lung.controllers._predictive_pid import PredictivePID
 from lung.controllers._original_pid import OriginalPID
 from lung.controllers._learned_bias import LearnedBias
 from lung.controllers._predictive_bias_pi import PredictiveBiasPI
 from lung.controllers._predictive_bias_const_pi import PredictiveBiasConstPI
 
-__all__ = ["Lookahead", "PID", "OriginalPID", "LearnedBias", "PredictiveBiasPI", \
-            "PredictiveBiasConstPI"]
+__all__ = [
+    "Lookahead",
+    "PID",
+    "PredictivePID",
+    "OriginalPID",
+    "LearnedBias",
+    "PredictiveBiasPI",
+    "PredictiveBiasConstPI",
+]
