@@ -14,15 +14,8 @@ class PredictiveBiasConstPI(Controller):
         self.c = 1.0
         self.storage = 3
         self.forecaster = LinearForecaster(self.storage)
-<<<<<<< HEAD
-        self.pid = PID([p, i, 0.], RC=RC)
-        self.base_controller = Lookahead(self.forecaster, self.pid,
-            lookahead_steps)
-
-=======
         self.pid = PID(self.waveform, [p, i, 0.0], RC=RC)
         self.base_controller = Lookahead(self.forecaster, self.pid, lookahead_steps)
->>>>>>> d8c1ce4e3ae4521f1b93e6209dd3e3238ff5e42e
 
     def feed(self, state, t):
         err = self.waveform.at(t) - state
