@@ -18,6 +18,8 @@ class PredictiveBiasPI(Controller):
 
     def feed(self, state, t):
         err = self.waveform.at(t) - state
+        cycle_phase = self.cycle_phase(t)
+
         self.bias = self.bias + np.sign(err) * self.bias_lr
-        base_control = self.base_controller.feed(state, t)
-        return (base_control + self.bias, self.u_out(t))
+        base_control = self.base_controller.feed(state, cycle_phase)
+        return (base_control + self.bias, self.u_out(cycle_phase))
