@@ -38,13 +38,12 @@ class Controller(abc.ABC):
         pass
 
     def u_out(self, t):
-        u_out = 0
         phase = self.phase(t)
+        u_out = np.zeros_like(phase)
+        u_out[np.equal(phase, Phase.RAMP_DOWN.value)] = 1
+        u_out[np.equal(phase, Phase.PEEP.value)] = 1
 
-        if phase == Phase.RAMP_DOWN or phase == Phase.PEEP:
-            u_out = 1
-
-        return u_out
+        return u_out if np.isscalar(t) else u_out[0]
 
     def dt(self, t):
         dt = max(0, t - self.time)
